@@ -18,6 +18,7 @@
 
 #include "gconf-list-model.h"
 
+#include <string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "gconf-util.h"
 
@@ -37,12 +38,26 @@ gconf_list_model_notify_func (GConfClient* client, guint cnxn_id, GConfEntry *en
 {
 	GSList *list;
 	const gchar *key;
+	char *path_str;
 	GConfListModel *list_model = user_data;
 	GtkTreeIter iter;
 	GtkTreePath *path;
 
 	key = gconf_entry_get_key (entry);
 
+	path_str = g_path_get_dirname (key);
+
+	if (strcmp (path_str, list_model->root_path) != 0)
+	  {
+	    g_free (path_str);
+	    return;
+	  }
+
+	g_free (path_str);
+
+	if (strncmp (key, list_model->root_path, strlen (list_model->root_path)) != 0)
+	    return;
+	
 	if (gconf_client_dir_exists (gconf_client_get_default (), key, NULL))
 		/* this is a directory -- ignore */
 		return;
@@ -286,6 +301,7 @@ gconf_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, gint co
 		default:
 			icon = blank_pixbuf;
 			g_warning ("unknown value type %d", gconf_entry_get_value (entry)->type);
+			break;
 		}
 
 		g_value_init (value, GDK_TYPE_PIXBUF);
@@ -299,6 +315,7 @@ gconf_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, gint co
 		break;
 
 	default:
+		break;
 	}
 }
 
